"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _stream = require("stream");
var _clientS = require("@aws-sdk/client-s3");
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _bluebird = _interopRequireDefault(require("bluebird"));
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */
// import { S3, config } from 'aws-sdk';

class Connector {
  constructor({
    debug,
    bucketName = process.env.BUCKET_NAME,
    timeout = Number(process.env.S3_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = msg => debug('%j', msg);
    this.bucketName = bucketName || 'undefined';
    this.bucket = new _clientS.S3Client({
      requestHandler: new _nodeHttpHandler.NodeHttpHandler({
        requestTimeout: timeout,
        connectionTimeout: timeout
      }),
      logger: (0, _log.defaultDebugLogger)(debug)
    });
  }
  putObject(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this._sendCommand(new _clientS.PutObjectCommand(params));
  }
  deleteObject(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this._sendCommand(new _clientS.DeleteObjectCommand(params));
  }
  getObject(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this._sendCommand(new _clientS.GetObjectCommand(params)).then(async response => ({
      ...response,
      Body: await response.Body.transformToString()
    }));
  }
  getObjectStream(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this._sendCommand(new _clientS.GetObjectCommand(params)).then(response => _stream.Readable.from(response.Body));
  }
  listObjects(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this._sendCommand(new _clientS.ListObjectsV2Command(params));
  }
  _sendCommand(command) {
    return _bluebird.default.resolve(this.bucket.send(command)).tap(this.debug).tapCatch(this.debug);
  }
}
var _default = exports.default = Connector;